@@ -4,7 +4,7 @@
 Checks sys.argv[0] == 'pyraf' to determine whether IRAF initialization
 is done verbosely or quietly.
 
-$Id: __init__.py 2020 2013-07-25 16:26:33Z sontag $
+$Id: __init__.py 2200 2014-06-04 17:40:38Z sontag $
 
 R. White, 2000 February 18
 """
@@ -245,28 +245,29 @@ except ImportError :
     # ok to skip this on Windows
     pass
 else :
-    def raise_limit( which, howmuch ) :
+    def raise_limit(which, howmuch):
 
         # We have to know the old limit so we don't ask to go above that.
         # Some systems don't let you use -1 for the max limit if the
         # max limit is already set.
-        n = resource.getrlimit( which )
+        oldlims = resource.getrlimit(which)
 
         # Raise it to the max.
-        if ( howmuch is None ) or ( howmuch == -1 ) :
-            n = ( n[1], n[1] )
+        if (howmuch is None) or (howmuch == -1) :
+            newlims = (oldlims[1], oldlims[1])
         else :
-            n = ( howmuch, n[1] )
+            newlims = (howmuch, oldlims[1])
 
         # Try to set it.
         try :
-            resource.setrlimit( which, n )
-        except resource.error :
+            resource.setrlimit(which, newlims)
+        # this naughty little bit of code can raise either resource.error,
+        # ValueError, or OSError, depending on the Python version.  Catch all.
+        except:
             # Well, we tried; this is nothing worth killing pyraf over,
             # though -- either we will get by anyway, or we will find
             # out later.
             pass
 
     # Currently, we just raise the stack limit.
-    raise_limit( resource.RLIMIT_STACK, None )
-
+    raise_limit(resource.RLIMIT_STACK, None)
