@@ -1,6 +1,6 @@
 """module iraftask.py -- defines IrafTask and IrafPkg classes
 
-$Id: iraftask.py 1935 2013-02-26 16:41:36Z sontag $
+$Id: iraftask.py 2247 2014-09-25 19:45:34Z sontag $
 
 R. White, 2000 June 26
 
@@ -601,7 +601,7 @@ class IrafTask(irafglobals.IrafTask, taskpars.TaskPars):
         try:
             if paramdict._has(paramname,exact=exact):
                 return self._getParFromDict(paramdict, paramname, pindex,
-                                                field, native, mode=mode, prompt=prompt)
+                                            field, native, mode=mode, prompt=prompt)
         except minmatch.AmbiguousKeyError, e:
             # re-raise the error with a bit more info
             raise IrafError("Cannot get parameter `%s'\n%s" %
@@ -902,7 +902,7 @@ class IrafTask(irafglobals.IrafTask, taskpars.TaskPars):
         if pmode == "a":
             pmode = mode or self.getMode()
         v = par.get(index=pindex,field=field,
-                                native=native,mode=pmode,prompt=prompt)
+                    native=native,mode=pmode,prompt=prompt)
         if isinstance(v,str) and v[:1] == ")":
 
             # parameter indirection: call getParam recursively
@@ -1561,10 +1561,10 @@ class IrafPkg(IrafCLTask, irafglobals.IrafPkg):
 
     def unlearn(self):
         """Resets parameters for all tasks in the package to their default values"""
-        # If package isn't loaded, just unlearn the top-level package parameters
-        if not self._loaded:
-            IrafCLTask.unlearn(self)
-        else:
+        # If package isn't loaded, just unlearn the top-level package parameters,
+        # otherwise unlearn top-level ones AND all sub tasks.
+        IrafCLTask.unlearn(self)
+        if self._loaded:
             # Loop over all tasks in the package
             for task in self._tasks.keys():
                 pyraf.iraf.getTask(task).unlearn()
