@@ -4,7 +4,7 @@ These are python stubs that are overloaded by a c version implementations.
 If the c versions do not exist, then these routines will do nothing
 
 
-$Id: wutil.py 2069 2013-10-09 15:33:36Z sontag $
+$Id: wutil.py 2119 2013-12-31 20:44:39Z sontag $
 """
 from __future__ import division # confidence high
 
@@ -508,17 +508,19 @@ def dumpspecs(outstream = None, skip_volatiles = False):
        pass
 
     out = "python exec = "+str(sys.executable)
-    out += "\npython ver = "+str(sys.version)
+    out += "\npython ver = "+sys.version.split()[0]
     out += "\nplatform = "+str(sys.platform)
     if not skip_volatiles:
         out += "\nPyRAF ver = "+pyrver
     out += "\nPY3K = "+str(capable.PY3K)
     out += "\nc.OF_GRAPHICS = "+str(capable.OF_GRAPHICS)
+    dco = 'not yet known'
     if hasattr(capable, 'get_dc_owner'): # rm hasattr at/after v2.2
         if skip_volatiles:
             out +="\n/dev/console owner = <skipped>"
         else:
-            out +="\n/dev/console owner = "+str(capable.get_dc_owner(False, True))
+            dco = capable.get_dc_owner(False, True)
+            out +="\n/dev/console owner = "+str(dco)
 
     if not capable.OF_GRAPHICS:
         if hasattr(capable, 'TKINTER_IMPORT_FAILED'):
@@ -541,6 +543,12 @@ def dumpspecs(outstream = None, skip_volatiles = False):
         out += "\nimported aqutil = "+str(bool(_has_aqutil))
         out += "\nimported xutil = "+str(bool(_has_xutil))
 
+        # Case of WUTIL_USING_X and not _has_xutil means either they don't have
+        # xutil library installed, or they do but they can't draw to screen
+        if WUTIL_USING_X and capable.OF_GRAPHICS and \
+           not _skipDisplay and not bool(_has_xutil):
+            # quick debug help here for case where xutil didn't build
+            out += '\n\tWARNING!  PyRAF may be missing the "xutil" library. See PyRAF FAQ 1.9'
         if 'PYRAFGRAPHICS' in os.environ:
             val = os.environ['PYRAFGRAPHICS']
             out += "\nPYRAFGRAPHICS = "+val
